@@ -1,5 +1,10 @@
 # import code from your package here to make them available outside the module like:
-from cythonbuilder.__version__ import __version__
 from cythonbuilder.cython_builder import cy_init, cy_clean, cy_build, cy_list, cy_interface
 from cythonbuilder.services import logger
-from cythonbuilder.logs import set_logger_debug_mode
\ No newline at end of file
+from cythonbuilder.logs import set_logger_debug_mode
+
+
+__version__ = "0.1.7"
+__last_build_datetime__ ="2022-05-13 16:14:12"
+__last_publish_version__ ="0.1.5"
+__last_publish_datetime__ ="2022-05-11 17:02:22"
